@@ -13,7 +13,6 @@
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import timeutils
-import six
 from stevedore import named
 
 from senlin.common import consts
@@ -43,8 +42,11 @@ def _event_data(action, phase=None, reason=None):
     action_name = action.action
     if action_name in [consts.NODE_OPERATION, consts.CLUSTER_OPERATION]:
         action_name = action.inputs.get('operation', action_name)
-    return dict(name=action.entity.name,
-                obj_id=action.entity.id[:8],
+    name = action.entity.name if action.entity else "Unknown"
+    obj_id = action.entity.id[:8] if action.entity else "Unknown"
+
+    return dict(name=name,
+                obj_id=obj_id,
                 action=action_name,
                 id=action.id[:8],
                 phase=phase,
@@ -73,7 +75,7 @@ def _dump(level, action, phase, reason, timestamp):
                                phase=phase, reason=reason, timestamp=timestamp)
     except Exception as ex:
         LOG.exception("Dispatcher failed to handle the event: %s",
-                      six.text_type(ex))
+                      str(ex))
 
 
 def critical(action, phase=None, reason=None, timestamp=None):
