@@ -11,10 +11,10 @@
 # under the License.
 
 import base64
+from unittest import mock
 
-import mock
+from oslo_config import cfg
 from oslo_utils import encodeutils
-import six
 
 from senlin.common import exception as exc
 from senlin.objects import node as node_ob
@@ -191,6 +191,76 @@ class TestNovaServerBasic(base.SenlinTestCase):
         mock_zone_info.assert_called_once_with(node_obj, fake_server)
         self.assertEqual('FAKE_ID', server_id)
 
+    @mock.patch.object(node_ob.Node, 'update')
+    def test_do_create_fail_create_instance_when_node_longer_exists(
+            self, mock_node_update):
+        mock_node_update.side_effect = [
+            None, exc.ResourceNotFound(type='Node', id='FAKE_NODE_ID')
+        ]
+
+        cc = mock.Mock()
+        nc = mock.Mock()
+        profile = server.ServerProfile('t', self.spec)
+        profile._computeclient = cc
+        profile._networkclient = nc
+        profile._rollback_ports = mock.Mock()
+        profile._rollback_instance = mock.Mock()
+        self._stubout_profile(profile, mock_image=True, mock_flavor=True,
+                              mock_keypair=True, mock_net=False)
+        node_obj = mock.Mock(id='FAKE_NODE_ID', index=123,
+                             availability_zone="AZ01",
+                             cluster_id='FAKE_CLUSTER_ID',
+                             data={
+                                'placement': {
+                                    'zone': 'AZ1',
+                                    'servergroup': 'SERVER_GROUP_1'
+                                }
+                             })
+        node_obj.name = 'TEST_SERVER'
+        fake_server = mock.Mock(id='FAKE_ID')
+        cc.server_create.return_value = fake_server
+        cc.server_get.return_value = fake_server
+
+        self.assertRaises(
+            exc.ResourceNotFound, profile.do_create, node_obj
+        )
+
+        profile._rollback_ports.assert_called_once()
+        profile._rollback_instance.assert_called_once()
+
+    @mock.patch.object(node_ob.Node, 'update')
+    def test_do_create_fail_create_port_when_node_longer_exists(
+            self, mock_node_update):
+        mock_node_update.side_effect = exc.ResourceNotFound(
+            type='Node', id='FAKE_NODE_ID'
+        )
+
+        cc = mock.Mock()
+        nc = mock.Mock()
+        profile = server.ServerProfile('t', self.spec)
+        profile._computeclient = cc
+        profile._networkclient = nc
+        profile._rollback_ports = mock.Mock()
+        profile._rollback_instance = mock.Mock()
+        self._stubout_profile(profile, mock_image=True, mock_flavor=True,
+                              mock_keypair=True, mock_net=False)
+        node_obj = mock.Mock(id='FAKE_NODE_ID', index=123,
+                             cluster_id='FAKE_CLUSTER_ID',
+                             data={
+                                'placement': {
+                                    'zone': 'AZ1',
+                                    'servergroup': 'SERVER_GROUP_1'
+                                }
+                             })
+        node_obj.name = 'TEST_SERVER'
+
+        self.assertRaises(
+            exc.ResourceNotFound, profile.do_create, node_obj
+        )
+
+        profile._rollback_ports.assert_called_once()
+        profile._rollback_instance.assert_not_called()
+
     def test_do_create_invalid_image(self):
         profile = server.ServerProfile('s2', self.spec)
         err = exc.EResourceCreation(type='server', message='boom')
@@ -599,10 +669,10 @@ class TestNovaServerBasic(base.SenlinTestCase):
                                node_obj)
         self.assertEqual('FAKE_ID', ex.resource_id)
         self.assertEqual('Failed in creating server: TIMEOUT.',
-                         six.text_type(ex))
-        mock_node_obj.assert_called_once_with(mock.ANY, node_obj.id,
-                                              {'data': node_obj.data})
-        cc.wait_for_server.assert_called_once_with('FAKE_ID')
+                         str(ex))
+        mock_node_obj.assert_not_called()
+        cc.wait_for_server.assert_called_once_with(
+            'FAKE_ID', timeout=cfg.CONF.default_nova_timeout)
 
     @mock.patch.object(node_ob.Node, 'update')
     def test_do_create_failed(self, mock_node_obj):
@@ -632,11 +702,166 @@ class TestNovaServerBasic(base.SenlinTestCase):
         mock_node_obj.assert_called_once_with(mock.ANY, node_obj.id,
                                               {'data': node_obj.data})
         self.assertEqual('Failed in creating server: creation failed.',
-                         six.text_type(ex))
+                         str(ex))
         self.assertIsNone(ex.resource_id)
         self.assertEqual(0, cc.wait_for_server.call_count)
         self.assertEqual(0, mock_zone_info.call_count)
 
+    @mock.patch.object(node_ob.Node, 'update')
+    @mock.patch.object(server.ServerProfile, 'do_delete')
+    def test_do_create_failed_with_server_id(self, mock_profile_delete,
+                                             mock_node_obj):
+        cc = mock.Mock()
+        profile = server.ServerProfile('t', self.spec)
+        profile._computeclient = cc
+        self._stubout_profile(profile, mock_image=True, mock_flavor=True,
+                              mock_keypair=True, mock_net=True)
+        mock_zone_info = self.patchobject(profile, '_update_zone_info')
+        node_obj = mock.Mock(id='FAKE_NODE_ID', index=123,
+                             cluster_id='FAKE_CLUSTER_ID',
+                             data={
+                                 'placement': {
+                                     'zone': 'AZ1',
+                                     'servergroup': 'SERVER_GROUP_1'
+                                 }
+                             })
+        node_obj.name = 'TEST_SERVER'
+        fake_server = mock.Mock(id='FAKE_ID')
+        cc.server_create.return_value = fake_server
+        cc.wait_for_server.side_effect = exc.InternalError(
+            code=500, message="creation failed.")
+
+        # do it
+        ex = self.assertRaises(exc.EResourceCreation, profile.do_create,
+                               node_obj)
+
+        # assertions
+        mock_node_obj.assert_not_called()
+        mock_profile_delete.assert_called_once_with(
+            node_obj, internal_ports=[{'id': 'FAKE_PORT'}])
+        self.assertEqual('Failed in creating server: creation failed.',
+                         str(ex))
+        self.assertEqual(1, cc.wait_for_server.call_count)
+        self.assertEqual(0, mock_zone_info.call_count)
+
+    def test_rollback_ports(self):
+        nc = mock.Mock()
+        nc.port_delete.return_value = None
+        nc.floatingip_delete.return_value = None
+        profile = server.ServerProfile('t', self.spec)
+        profile._networkclient = nc
+
+        ports = [
+            {
+                'id': 'FAKE_PORT_ID',
+                'remove': True
+            },
+            {
+                'floating': {
+                    'remove': True,
+                    'id': 'FAKE_FLOATING_ID',
+                },
+                'id': 'FAKE_PORT_ID',
+                'remove': True
+            },
+            {
+                'floating': {
+                    'remove': False,
+                    'id': 'FAKE_FLOATING_ID',
+                },
+                'id': 'FAKE_PORT_ID',
+                'remove': False
+            }
+        ]
+
+        node_obj = mock.Mock(id='NODE_ID', cluster_id='', index=-1, data={})
+
+        profile._rollback_ports(node_obj, ports)
+
+        nc.port_delete.assert_called()
+        nc.floatingip_delete.assert_called_once_with('FAKE_FLOATING_ID')
+
+    def test_rollback_with_no_ports(self):
+        nc = mock.Mock()
+        nc.port_delete.return_value = None
+        nc.floatingip_delete.return_value = None
+        profile = server.ServerProfile('t', self.spec)
+        profile._networkclient = nc
+
+        ports = []
+
+        node_obj = mock.Mock(id='NODE_ID', cluster_id='', index=-1, data={})
+
+        profile._rollback_ports(node_obj, ports)
+
+        nc.port_delete.assert_not_called()
+        nc.floatingip_delete.assert_not_called()
+
+    def test_rollback_ports_with_internal_error(self):
+        nc = mock.Mock()
+        nc.port_delete.return_value = None
+        nc.floatingip_delete.side_effect = exc.InternalError()
+        profile = server.ServerProfile('t', self.spec)
+        profile._networkclient = nc
+
+        ports = [{
+            'floating': {
+                'remove': True,
+                'id': 'FAKE_FLOATING_ID',
+            },
+            'id': 'FAKE_PORT_ID',
+            'remove': True
+        }]
+
+        node_obj = mock.Mock(id='NODE_ID', cluster_id='', index=-1, data={})
+
+        profile._rollback_ports(node_obj, ports)
+
+        nc.port_delete.assert_not_called()
+        nc.floatingip_delete.assert_called_once_with('FAKE_FLOATING_ID')
+
+    def test_rollback_instance(self):
+        cc = mock.Mock()
+        cc.port_delete.return_value = None
+        profile = server.ServerProfile('t', self.spec)
+        profile._computeclient = cc
+
+        server_obj = mock.Mock(id='SERVER_ID')
+
+        node_obj = mock.Mock(id='NODE_ID', cluster_id='', index=-1, data={})
+
+        profile._rollback_instance(node_obj, server_obj)
+
+        cc.server_force_delete.assert_called_once_with('SERVER_ID', True)
+
+    def test_rollback_with_no_instance(self):
+        cc = mock.Mock()
+        cc.port_delete.return_value = None
+        profile = server.ServerProfile('t', self.spec)
+        profile._computeclient = cc
+
+        server_obj = None
+
+        node_obj = mock.Mock(id='NODE_ID', cluster_id='', index=-1, data={})
+
+        profile._rollback_instance(node_obj, server_obj)
+
+        cc.server_force_delete.assert_not_called()
+
+    def test_rollback_instance_with_internal_error(self):
+        cc = mock.Mock()
+        cc.server_force_delete.side_effect = exc.InternalError()
+        profile = server.ServerProfile('t', self.spec)
+        profile._computeclient = cc
+
+        server_obj = mock.Mock(id='SERVER_ID')
+
+        node_obj = mock.Mock(id='NODE_ID', cluster_id='', index=-1, data={})
+
+        profile._rollback_instance(node_obj, server_obj)
+
+        cc.server_force_delete.assert_called_once_with('SERVER_ID', True)
+
     def test_do_delete_ok(self):
         profile = server.ServerProfile('t', self.spec)
 
@@ -651,7 +876,8 @@ class TestNovaServerBasic(base.SenlinTestCase):
 
         self.assertTrue(res)
         cc.server_delete.assert_called_once_with('FAKE_ID', True)
-        cc.wait_for_server_delete.assert_called_once_with('FAKE_ID', None)
+        cc.wait_for_server_delete.assert_called_once_with(
+            'FAKE_ID', timeout=cfg.CONF.default_nova_timeout)
 
     def test_do_delete_no_physical_id(self):
         profile = server.ServerProfile('t', self.spec)
@@ -732,7 +958,8 @@ class TestNovaServerBasic(base.SenlinTestCase):
         nc.floatingip_delete.assert_called_once_with('FAKE_FLOATING_ID')
         nc.port_delete.assert_called_once_with('FAKE_PORT_ID')
         cc.server_delete.assert_called_once_with('FAKE_ID', True)
-        cc.wait_for_server_delete.assert_called_once_with('FAKE_ID', None)
+        cc.wait_for_server_delete.assert_called_once_with(
+            'FAKE_ID', timeout=cfg.CONF.default_nova_timeout)
 
     def test_do_delete_ignore_missing_force(self):
         profile = server.ServerProfile('t', self.spec)
@@ -747,7 +974,8 @@ class TestNovaServerBasic(base.SenlinTestCase):
 
         self.assertTrue(res)
         cc.server_force_delete.assert_called_once_with('FAKE_ID', False)
-        cc.wait_for_server_delete.assert_called_once_with('FAKE_ID', None)
+        cc.wait_for_server_delete.assert_called_once_with(
+            'FAKE_ID', timeout=cfg.CONF.default_nova_timeout)
 
     @mock.patch.object(node_ob.Node, 'update')
     def test_do_delete_with_delete_failure(self, mock_node_obj):
@@ -776,7 +1004,7 @@ class TestNovaServerBasic(base.SenlinTestCase):
         mock_node_obj.assert_called_once_with(mock.ANY, obj.id,
                                               {'data': obj.data})
         self.assertEqual("Failed in deleting server 'FAKE_ID': "
-                         "Nova Error.", six.text_type(ex))
+                         "Nova Error.", str(ex))
         cc.server_delete.assert_called_once_with('FAKE_ID', True)
         self.assertEqual(0, cc.wait_for_server_delete.call_count)
         nc.port_delete.assert_called_once_with('FAKE_PORT_ID')
@@ -800,7 +1028,7 @@ class TestNovaServerBasic(base.SenlinTestCase):
 
         mock_node_obj.assert_not_called()
         self.assertEqual("Failed in deleting server 'FAKE_ID': "
-                         "Nova Error.", six.text_type(ex))
+                         "Nova Error.", str(ex))
         cc.server_force_delete.assert_called_once_with('FAKE_ID', True)
         self.assertEqual(0, cc.wait_for_server_delete.call_count)
         nc.port_delete.assert_not_called()
@@ -832,9 +1060,10 @@ class TestNovaServerBasic(base.SenlinTestCase):
         mock_node_obj.assert_called_once_with(mock.ANY, obj.id,
                                               {'data': obj.data})
         self.assertEqual("Failed in deleting server 'FAKE_ID': TIMEOUT.",
-                         six.text_type(ex))
+                         str(ex))
         cc.server_delete.assert_called_once_with('FAKE_ID', True)
-        cc.wait_for_server_delete.assert_called_once_with('FAKE_ID', 20)
+        cc.wait_for_server_delete.assert_called_once_with('FAKE_ID',
+                                                          timeout=20)
         nc.port_delete.assert_called_once_with('FAKE_PORT_ID')
 
     @mock.patch.object(node_ob.Node, 'update')
@@ -867,11 +1096,12 @@ class TestNovaServerBasic(base.SenlinTestCase):
                                profile.do_delete, test_server, timeout=20)
 
         self.assertEqual("Failed in deleting server 'FAKE_ID': TIMEOUT.",
-                         six.text_type(ex))
+                         str(ex))
         mock_node_obj.assert_called_once_with(
             mock.ANY, test_server.id, {'data': {'internal_ports': []}})
         cc.server_delete.assert_called_once_with('FAKE_ID', True)
-        cc.wait_for_server_delete.assert_called_once_with('FAKE_ID', 20)
+        cc.wait_for_server_delete.assert_called_once_with('FAKE_ID',
+                                                          timeout=20)
         nc.port_delete.assert_called_once_with('FAKE_PORT_ID')
 
     @mock.patch.object(node_ob.Node, 'update')
@@ -897,10 +1127,11 @@ class TestNovaServerBasic(base.SenlinTestCase):
                                profile.do_delete, test_server, timeout=20)
 
         self.assertEqual("Failed in deleting server 'FAKE_ID': TIMEOUT.",
-                         six.text_type(ex))
+                         str(ex))
         mock_node_obj.assert_not_called()
         cc.server_delete.assert_called_once_with('FAKE_ID', True)
-        cc.wait_for_server_delete.assert_called_once_with('FAKE_ID', 20)
+        cc.wait_for_server_delete.assert_called_once_with('FAKE_ID',
+                                                          timeout=20)
         nc.port_delete.assert_not_called()
 
     def test_do_get_details(self):
@@ -1040,6 +1271,51 @@ class TestNovaServerBasic(base.SenlinTestCase):
         self.assertEqual(expected, res)
         cc.server_get.assert_called_once_with('FAKE_ID')
 
+    def test_do_get_details_flavor_no_id_key(self):
+        cc = mock.Mock()
+        profile = server.ServerProfile('t', self.spec)
+        profile._computeclient = cc
+        node_obj = mock.Mock(physical_id='FAKE_ID')
+
+        # Test normal path
+        nova_server = mock.Mock()
+        nova_server.to_dict.return_value = {
+            'addresses': {
+                'private': [{
+                    'version': 4,
+                    'addr': '10.0.0.3',
+                }]
+            },
+            'flavor': {
+                'original_name': 'FAKE_FLAVOR',
+            },
+            'id': 'FAKE_ID',
+            'image': {},
+            'attached_volumes': [{
+                'id': 'FAKE_VOLUME',
+            }],
+            'security_groups': [{'name': 'default'}],
+        }
+        cc.server_get.return_value = nova_server
+        cc.flavor_find.return_value = mock.PropertyMock(id='FAKE_FLAVOR_ID')
+
+        res = profile.do_get_details(node_obj)
+        expected = {
+            'flavor': 'FAKE_FLAVOR_ID',
+            'id': 'FAKE_ID',
+            'image': {},
+            'attached_volumes': ['FAKE_VOLUME'],
+            'addresses': {
+                'private': [{
+                    'version': 4,
+                    'addr': '10.0.0.3',
+                }]
+            },
+            'security_groups': 'default',
+        }
+        self.assertEqual(expected, res)
+        cc.server_get.assert_called_once_with('FAKE_ID')
+
     def test_do_get_details_image_no_id_key(self):
         cc = mock.Mock()
         profile = server.ServerProfile('t', self.spec)
@@ -1427,7 +1703,7 @@ class TestNovaServerBasic(base.SenlinTestCase):
 
         self.assertEqual("Failed in found server 'FAKE_ID': "
                          "No Server found.",
-                         six.text_type(ex))
+                         str(ex))
         cc.server_get.assert_called_once_with('FAKE_ID')
 
     def test_do_healthcheck_active(self):
@@ -1691,7 +1967,7 @@ class TestNovaServerBasic(base.SenlinTestCase):
 
         self.assertEqual("Failed in rebuilding server 'FAKE_ID': "
                          "FAKE_ID not found.",
-                         six.text_type(ex))
+                         str(ex))
         cc.server_get.assert_called_once_with('FAKE_ID')
 
     def test_handle_rebuild_failed_rebuild(self):
@@ -1711,7 +1987,7 @@ class TestNovaServerBasic(base.SenlinTestCase):
 
         self.assertEqual("Failed in rebuilding server 'FAKE_ID': "
                          "cannot rebuild.",
-                         six.text_type(ex))
+                         str(ex))
         cc.server_get.assert_called_once_with('FAKE_ID')
         cc.server_rebuild.assert_called_once_with('FAKE_ID', '123',
                                                   'FAKE_SERVER_NAME',
@@ -1734,7 +2010,7 @@ class TestNovaServerBasic(base.SenlinTestCase):
                                node_obj)
 
         self.assertEqual("Failed in rebuilding server 'FAKE_ID': "
-                         "timeout.", six.text_type(ex))
+                         "timeout.", str(ex))
         cc.server_get.assert_called_once_with('FAKE_ID')
         cc.server_rebuild.assert_called_once_with('FAKE_ID', '123',
                                                   'FAKE_SERVER_NAME',
@@ -1786,7 +2062,7 @@ class TestNovaServerBasic(base.SenlinTestCase):
                                node_obj)
 
         self.assertEqual("The value 'None' is not a valid string.",
-                         six.text_type(ex))
+                         str(ex))
         cc.server_get.assert_called_once_with('FAKE_ID')
         cc.server_rebuild.assert_not_called()
         self.assertEqual(0, cc.wait_for_server.call_count)
@@ -1867,7 +2143,7 @@ class TestNovaServerBasic(base.SenlinTestCase):
                                node_obj)
 
         self.assertEqual("Failed in suspend server 'FAKE_ID': "
-                         "timeout.", six.text_type(ex))
+                         "timeout.", str(ex))
         cc.server_suspend.assert_called_once_with('FAKE_ID')
         cc.wait_for_server.assert_called_once_with('FAKE_ID', 'SUSPENDED')
 
@@ -1902,7 +2178,7 @@ class TestNovaServerBasic(base.SenlinTestCase):
                                node_obj)
 
         self.assertEqual("Failed in resume server 'FAKE_ID': "
-                         "timeout.", six.text_type(ex))
+                         "timeout.", str(ex))
         cc.server_resume.assert_called_once_with('FAKE_ID')
         cc.wait_for_server.assert_called_once_with('FAKE_ID', 'ACTIVE')
 
@@ -1936,7 +2212,7 @@ class TestNovaServerBasic(base.SenlinTestCase):
                                node_obj)
 
         self.assertEqual("Failed in start server 'FAKE_ID': "
-                         "timeout.", six.text_type(ex))
+                         "timeout.", str(ex))
         cc.server_start.assert_called_once_with('FAKE_ID')
         cc.wait_for_server.assert_called_once_with('FAKE_ID', 'ACTIVE')
 
@@ -1971,7 +2247,7 @@ class TestNovaServerBasic(base.SenlinTestCase):
                                node_obj)
 
         self.assertEqual("Failed in stop server 'FAKE_ID': "
-                         "timeout.", six.text_type(ex))
+                         "timeout.", str(ex))
         cc.server_stop.assert_called_once_with('FAKE_ID')
         cc.wait_for_server.assert_called_once_with('FAKE_ID', 'SHUTOFF')
 
@@ -2040,7 +2316,7 @@ class TestNovaServerBasic(base.SenlinTestCase):
                                node_obj)
 
         self.assertEqual("Failed in pause server 'FAKE_ID': "
-                         "timeout.", six.text_type(ex))
+                         "timeout.", str(ex))
         cc.server_pause.assert_called_once_with('FAKE_ID')
         cc.wait_for_server.assert_called_once_with('FAKE_ID', 'PAUSED')
 
@@ -2074,7 +2350,7 @@ class TestNovaServerBasic(base.SenlinTestCase):
                                node_obj)
 
         self.assertEqual("Failed in unpause server 'FAKE_ID': "
-                         "timeout.", six.text_type(ex))
+                         "timeout.", str(ex))
         cc.server_unpause.assert_called_once_with('FAKE_ID')
         cc.wait_for_server.assert_called_once_with('FAKE_ID', 'ACTIVE')
 
@@ -2129,7 +2405,7 @@ class TestNovaServerBasic(base.SenlinTestCase):
                                image='FAKE_IMAGE')
 
         self.assertEqual("Failed in rescue server 'FAKE_ID': "
-                         "timeout.", six.text_type(ex))
+                         "timeout.", str(ex))
         cc.server_rescue.assert_called_once_with('FAKE_ID',
                                                  admin_pass='new_pass',
                                                  image_ref='FAKE_IMAGE')
@@ -2166,7 +2442,7 @@ class TestNovaServerBasic(base.SenlinTestCase):
                                node_obj)
 
         self.assertEqual("Failed in unrescue server 'FAKE_ID': "
-                         "timeout.", six.text_type(ex))
+                         "timeout.", str(ex))
         cc.server_unrescue.assert_called_once_with('FAKE_ID')
         cc.wait_for_server.assert_called_once_with('FAKE_ID', 'ACTIVE')
 
@@ -2200,7 +2476,7 @@ class TestNovaServerBasic(base.SenlinTestCase):
                                node_obj)
 
         self.assertEqual("Failed in migrate server 'FAKE_ID': "
-                         "timeout.", six.text_type(ex))
+                         "timeout.", str(ex))
         cc.server_migrate.assert_called_once_with('FAKE_ID')
         cc.wait_for_server.assert_called_once_with('FAKE_ID', 'ACTIVE')
 
@@ -2234,7 +2510,7 @@ class TestNovaServerBasic(base.SenlinTestCase):
                                node_obj)
 
         self.assertEqual("Failed in snapshot server 'FAKE_ID': "
-                         "timeout.", six.text_type(ex))
+                         "timeout.", str(ex))
         cc.wait_for_server.assert_called_once_with('FAKE_ID', 'ACTIVE')
 
     def test_handle_restore(self):
